:mod:`art.defences.detector.poisoning`
======================================
.. automodule:: art.defences.detector.poisoning

Base Class
----------
.. autoclass:: PoisonFilteringDefence
   :members:

Activation Defence
------------------
.. autoclass:: ActivationDefence
   :members:

Data Provenance Defense
-----------------------
.. autoclass:: ProvenanceDefense
   :members:

Reject on Negative Impact (RONI) Defense
----------------------------------------
.. autoclass:: RONIDefense
   :members:

Spectral Signature Defense
--------------------------
.. autoclass:: SpectralSignatureDefense
   :members:
